Work toward ONOS-1451: Separate Event Key space per instance

Misc changes and cleanup:
* Added new class OnosInstanceId
* Replace (as appropriate) the string controllerId (and associated methods)
  with the new class OnosInstanceId
* Renaming: Host -> Device
  - Method getDeviceID -> getHostID
  - Changed Host Key ID prefix 'D' to 'H'
  - Few renaming of Host -> Device inside Javadoc

Change-Id: I59c20d68277ecde2f7df4e7097a4a52d5786df1b
diff --git a/src/main/java/net/onrc/onos/core/topology/HostEvent.java b/src/main/java/net/onrc/onos/core/topology/HostEvent.java
index c35764e..ebaf688 100644
--- a/src/main/java/net/onrc/onos/core/topology/HostEvent.java
+++ b/src/main/java/net/onrc/onos/core/topology/HostEvent.java
@@ -18,7 +18,7 @@
  * <p/>
  * Host event differ from other events.
  * Host Event represent add/remove of attachmentPoint.
  * Not add/remove of the DeviceObject itself.
  * <p/>
  * Multiple attachmentPoints can be specified to batch events into 1 object.
  * Each should be treated as independent events.
@@ -146,16 +146,16 @@
     }
 
     // Assuming mac is unique cluster-wide
-    public static ByteBuffer getDeviceID(final byte[] mac) {
+    public static ByteBuffer getHostID(final byte[] mac) {
         return (ByteBuffer) ByteBuffer.allocate(2 + mac.length)
-                .putChar('D').put(mac).flip();
+                .putChar('H').put(mac).flip();
     }
 
     public byte[] getID() {
-        return getDeviceID(mac.toBytes()).array();
+        return getHostID(mac.toBytes()).array();
     }
 
     public ByteBuffer getIDasByteBuffer() {
-        return getDeviceID(mac.toBytes());
+        return getHostID(mac.toBytes());
     }
 }
@@ -18,7 +18,7 @@
  * Host event differ from other events.
  * Host Event represent add/remove of attachmentPoint.
- * Not add/remove of the DeviceObject itself.
+ * Not add/remove of the Host Object itself.
  * <p/>
  * Multiple attachmentPoints can be specified to batch events into 1 object.